@@ -1,4 +1,5 @@
 from enum import Enum
+
 SIM_HOST = "https://simulator.home-connect.com"
 API_HOST = "https://api.home-connect.com"
 ENDPOINT_AUTHORIZE = "/security/oauth/authorize"
@@ -7,10 +8,14 @@ DEFAULT_SCOPES = [ 'IdentifyAppliance', 'Monitor', 'Control', 'Settings'  ]
 
 class Events(str,Enum):
     """ Enum for special event types """
-    DATA_REFRESHED = "DATA_REFRESHED"
+    DATA_CHANGED = "DATA_CHANGED"
     CONNECTION_CHANGED = "CONNECTION_CHANGED"
-    DEFAULT = "DEFAULT"
+    CONNECTED = "CONNECTED"
+    DISCONNECTED = "DISCONNECTED"
+    PAIRED = "PAIRED"
+    DEPAIRED = "DEPAIRED"
+    PROGRAM_STARTED = "PROGRAM_STARTED"
+    PROGRAM_FINISHED = "PROGRAM_FINISHED"
+    UNHANDLED = "UNHANDLED"
 
 
-EVENT_DATA_REFRESHED = "DATA_REFRESHED"
-EVENT_CONNECTION_CHANGED = "CONNECTION_CHANGED"
